@@ -4,17 +4,16 @@ use strict;
 use warnings;
 
 use Carp 'confess';
-use Scalar::Util 'weaken';
 use File::Path 'mkpath';
-use File::Basename 'dirname', 'basename';
 
 use SPVM ();
-
 use SPVM::Builder::CC;
 use SPVM::Builder::Compiler;
-use SPVM::Builder::Runtime;
-use SPVM::Builder::Env;
-use SPVM::Builder::Stack;
+use SPVM::Builder::Util::API;
+use SPVM::BlessedObject;
+use SPVM::BlessedObject::Array;
+use SPVM::BlessedObject::Class;
+use SPVM::BlessedObject::String;
 
 # Fields
 sub build_dir {
@@ -144,12 +143,7 @@ sub build {
   
   my $output_dir = $options->{output_dir};
   
-  unless (defined $output_dir) {
-    if ($is_jit) {
-      $output_dir = SPVM::Builder::Util::create_build_lib_path($build_dir);
-      mkpath $output_dir;
-    }
-  }
+  my $runtime = $options->{runtime};
   
   # Config
   my $config;
@@ -176,14 +170,22 @@ sub build {
   
   $config->output_dir($output_dir);
   
-  my $runtime = $options->{runtime};
-  
   my $cc_options = {build_dir => $build_dir};
   
   if (exists $options->{force}) {
     $cc_options->{force} = $options->{force};
   }
   
+  unless (defined $build_dir) {
+    confess "A build directory must be defined. Perhaps the SPVM_BUILD_DIR environment variable is not set.";
+  }
+  
+  mkpath $build_dir;
+  
+  unless (-d $build_dir) {
+    confess "[Unexpected Error]A build directory must exists.";
+  }
+  
   my $cc = SPVM::Builder::CC->new(%$cc_options);
   
   my $compile_and_link_options = {config => $config, runtime => $runtime};
