@@ -614,21 +614,18 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
       error_id = env->set_command_info_program_name(env, stack, obj_program_name);
       
       if (error_id) {
-        env->print_stderr(env, stack, env->get_exception(env, stack));
-        fprintf(spvm_stderr, "\\n");
+        env->die(env, stack, env->get_chars(env, stack, env->get_exception(env, stack)), __func__, __FILE__, __LINE__);
       }
       else {
         error_id = env->set_command_info_argv(env, stack, obj_argv);
         
         if (error_id) {
-          env->print_stderr(env, stack, env->get_exception(env, stack));
-          fprintf(spvm_stderr, "\\n");
+          env->die(env, stack, env->get_chars(env, stack, env->get_exception(env, stack)), __func__, __FILE__, __LINE__);
         }
         else {
           error_id = env->set_command_info_base_time(env, stack, base_time);
           if (error_id) {
-            env->print_stderr(env, stack, env->get_exception(env, stack));
-            fprintf(spvm_stderr, "\\n");
+            env->die(env, stack, env->get_chars(env, stack, env->get_exception(env, stack)), __func__, __FILE__, __LINE__);
           }
         }
       }
@@ -640,48 +637,31 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
   if (!error_id) {
     const char* class_name = "$class_name";
     
-    void* class_basic_type = env->api->runtime->get_basic_type_by_name(env->runtime, class_name);
-    void* method = env->api->basic_type->get_method_by_name(env->runtime, class_basic_type, "main");
+    error_id = env->check_bootstrap_method(env, stack, class_name);
     
-    if (method) {
-      int32_t is_class_method = env->api->method->is_class_method(env->runtime, method);
-      
-      if (is_class_method) {
-        int32_t args_length = env->api->method->get_args_length(env->runtime, method);
-        
-        if (!(args_length == 0)) {
-          fprintf(spvm_stderr, "The length of the arguments of the \\\"main\\\" method in the \\\"%s\\\" class must be 0.\\n", class_name);
-          error_id = SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS;
-        }
-      }
-      else {
-        fprintf(spvm_stderr, "The \\\"main\\\" method in the \\\"%s\\\" class must be a class method.\\n", class_name);
-        error_id = SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS;
-      }
+    if (error_id) {
+      env->die(env, stack, env->get_chars(env, stack, env->get_exception(env, stack)), __func__, __FILE__, __LINE__);
     }
     else {
-      fprintf(spvm_stderr, "The \\\"main\\\" method in the \\\"%s\\\" class must be defined.\\n", class_name);
-      error_id = SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS;
-    }
-    
-    if (!error_id) {
       error_id = env->call_init_methods(env, stack);
-      if (error_id) {
-        env->print_stderr(env, stack, env->get_exception(env, stack));
-        fprintf(spvm_stderr, "\\n");
-      }
-      else {
+      if (!error_id) {
+        void* class_basic_type = env->api->runtime->get_basic_type_by_name(env->runtime, class_name);
+        void* method = env->api->basic_type->get_method_by_name(env->runtime, class_basic_type, "main");
+        
         int32_t args_width = 0;
         error_id = env->call_method(env, stack, method, args_width);
-        
         if (error_id) {
-          env->print_stderr(env, stack, env->get_exception(env, stack));
-          fprintf(spvm_stderr, "\\n");
+          env->die(env, stack, env->get_chars(env, stack, env->get_exception(env, stack)), __func__, __FILE__, __LINE__);
         }
       }
     }
   }
   
+  if (error_id) {
+    env->print_stderr(env, stack, env->get_exception(env, stack));
+    fprintf(spvm_stderr, "\\n");
+  }
+  
   env->destroy_class_vars(env, stack);
   
   env->free_stack(env, stack);
