@@ -1892,7 +1892,7 @@ Prints a string and C<\n> to stdout. This is the same operator as the say operat
 
 =head2 warn
 
-C<void (*warn)(SPVM_ENV* env, SPVM_VALUE* stack, void* string, const char* class_dir, const char* class_rel_file, int32_t line);>
+C<void (*warn)(SPVM_ENV* env, SPVM_VALUE* stack, void* string, const char* file, int32_t line);>
 
 Operates the warn operator.
 
@@ -1914,6 +1914,14 @@ C<FILE* (*spvm_stderr)(SPVM_ENV* env, SPVM_VALUE* stack);>
 
 Gets the standard error opened for SPVM.
 
+=head2 check_bootstrap_method
+
+C<int32_t (*check_bootstrap_method)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name);>
+
+Checks the definition of the bootstrap method.
+
+If it is invalid, return non-zero, otherwise return 0.
+
 =head1 Native API IDs
 
 Native APIs have its IDs. These IDs are permanently same for the binary compatibility after the future release C<v1.0>.
@@ -2130,6 +2138,7 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   209 spvm_stdin,
   210 spvm_stdout,
   211 spvm_stderr,
+  212 check_bootstrap_method
 
 =head1 Constant Values
 
